@@ -12,14 +12,13 @@ import numpy as np
 from multiprocessing.pool import ThreadPool, Pool
 import cdsapi
 import requests
+from tethys_cdsapi.utils import file_naming, available_parameters
 import urllib3
 urllib3.disable_warnings()
 
 ##############################################
 ### Parameters
 
-ds_cols = ['feature', 'parameter', 'frequency_interval', 'aggregation_statistic', 'units', 'wrf_standard_name', 'cf_standard_name', 'scale_factor']
-
 months = ['01', '02', '03',
          '04', '05', '06',
          '07', '08', '09',
@@ -46,26 +45,6 @@ times = ['00:00', '01:00', '02:00',
         '18:00', '19:00', '20:00',
         '21:00', '22:00', '23:00']
 
-file_naming = '{param}_{from_year}-{to_year}_{product}.nc'
-
-available_parameters = {'reanalysis-era5-land': [
-            '10m_u_component_of_wind', '10m_v_component_of_wind', '2m_dewpoint_temperature',
-            '2m_temperature', 'evaporation_from_bare_soil', 'evaporation_from_open_water_surfaces_excluding_oceans',
-            'evaporation_from_the_top_of_canopy', 'evaporation_from_vegetation_transpiration', 'forecast_albedo', 'lake_bottom_temperature', 'lake_ice_depth', 'lake_ice_temperature',
-            'lake_mix_layer_depth', 'lake_mix_layer_temperature', 'lake_shape_factor',
-            'lake_total_layer_temperature', 'leaf_area_index_high_vegetation', 'leaf_area_index_low_vegetation', 'potential_evaporation', 'runoff', 'skin_reservoir_content',
-            'skin_temperature', 'snow_albedo', 'snow_cover',
-            'snow_density', 'snow_depth', 'snow_depth_water_equivalent',
-            'snow_evaporation', 'snowfall', 'snowmelt',
-            'soil_temperature_level_1', 'soil_temperature_level_2', 'soil_temperature_level_3',
-            'soil_temperature_level_4', 'sub_surface_runoff', 'surface_latent_heat_flux',
-            'surface_net_solar_radiation', 'surface_net_thermal_radiation', 'surface_pressure',
-            'surface_runoff', 'surface_sensible_heat_flux', 'surface_solar_radiation_downwards',
-            'surface_thermal_radiation_downwards', 'temperature_of_snow_layer', 'total_evaporation',
-            'total_precipitation', 'volumetric_soil_water_layer_1', 'volumetric_soil_water_layer_2',
-            'volumetric_soil_water_layer_3', 'volumetric_soil_water_layer_4',
-        ]}
-
 
 ########################################
 ### Main classes
